FeedbackStrings class

Constructors

FeedbackStrings({String pageTitle = 'Send Feedback', String feedbackInputLabel = 'Your feedback', String feedbackInputHint = 'Tell us what you think...', String feedbackInputValidationError = 'Please enter your feedback.', String submitButtonLabel = 'Submit', String sentSuccessfully = 'Thank you for your feedback!', String sendError = 'Something went wrong. Please try again later.', String nameLabel = 'Name (Optional)', String nameHint = 'Enter your name', String emailLabel = 'Email (Optional)', String emailHint = 'Enter your email', String attachmentLabel = 'Attach a file (Optional)', String attachFileLabel = 'Attach File', String removeAttachment = 'Remove Attachment', String emailValidationError = 'Please enter a valid email.'})
const
FeedbackStrings.auto()
Create FeedbackStrings with automatic language detection Detects the device language and returns appropriate translations
factory
FeedbackStrings.forLanguage(String languageCode)
Create FeedbackStrings for a specific language
factory

Properties

attachFileLabel String
final
attachmentLabel String
final
emailHint String
final
emailLabel String
final
emailValidationError String
final
feedbackInputHint String
final
feedbackInputLabel String
final
feedbackInputValidationError String
final
hashCode int
The hash code for this object.
no setterinherited
nameHint String
final
nameLabel String
final
pageTitle String
final
removeAttachment String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendError String
final
sentSuccessfully String
final
submitButtonLabel String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited