FeedbackRequest class

Constructors

FeedbackRequest({required String content, required String platform, required String version, String? name, String? email, String? attachmentPath, bool isPremium = false})

Properties

attachmentPath String?
final
content String
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
isPremium bool
final
name String?
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFormData() → FormData
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited